summaryrefslogtreecommitdiff
path: root/src/parser/cvc/cvc_input.h
diff options
context:
space:
mode:
authorAndrew Reynolds <andrew.j.reynolds@gmail.com>2020-02-24 15:37:48 -0600
committerGitHub <noreply@github.com>2020-02-24 15:37:48 -0600
commit9fbe415992986d33d09b3b9e5049ebc22d20790a (patch)
tree986c6a139e2de4d324aa470b029af88cbcda301f /src/parser/cvc/cvc_input.h
parentc4f2ca4c1931f91a9647f0daa032ee9417f1b382 (diff)
Convert parser input interface to api::Term (#3809)
Diffstat (limited to 'src/parser/cvc/cvc_input.h')
-rw-r--r--src/parser/cvc/cvc_input.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/parser/cvc/cvc_input.h b/src/parser/cvc/cvc_input.h
index 098efd580..50be82903 100644
--- a/src/parser/cvc/cvc_input.h
+++ b/src/parser/cvc/cvc_input.h
@@ -57,12 +57,12 @@ class CvcInput : public AntlrInput {
*/
Command* parseCommand() override;
/** Parse an expression from the input. Returns a null <code>Expr</code>
* if there is no expression there to parse.
*
* @throws ParserException if an error is encountered during parsing.
*/
- Expr parseExpr() override;
+ api::Term parseExpr() override;
private:
/** Initialize the class. Called from the constructors once the input stream
generated by cgit on debian on lair
@@ -57,12 +57,12 @@ class CvcInput : public AntlrInput {
*/
Command* parseCommand() override;
- /** Parse an expression from the input. Returns a null <code>Expr</code>
+ /** Parse an expression from the input. Returns a null <code>api::Term</code>
* if there is no expression there to parse.
*
contact matthew@masot.net with questions or feedback